<?php
require_once 'includes/access.php';
require_once 'includes/util.php';

const PERSISTENT_DATA_DIR = '/var/lib/dp18-web-frontend';

$redirect = filter_input(INPUT_GET, 'redir', FILTER_SANITIZE_URL, [ 'options' => [ 'default' => '/index.php' ]]);

function set_if_none(&$var, $value) {
    if (!isset($var)) {
        $var = $value;
    }
}

function make_alert_success($msg) {
    global $redirect;
    return '<div class="alert alert-success">' . $msg . ' <a href="' . $redirect . '" class="alert-link">Torna indietro</a></div>';
}

function make_alert_error($msg) {
    return '<div class="alert alert-danger">' . $msg . '</div>';
}

function make_bootstrap_form_input($attributes = [], $options = [], $value = '') {
    $attributes['value'] = $value;
    set_if_none($attributes['type'], 'text');
    set_if_none($attributes['class'], 'form-control');
    set_if_none($attributes['placeholder'], get_or_else($attributes['title']));
    
    echo '<input';
    foreach ($attributes as $attr => $value) {
        echo "\n$attr=\"" . htmlspecialchars($value) . '"';
    }
    echo '/>';
    if (isset($options['addon'])) {
        echo '<span class="input-group-addon">';
        echo $options['addon'];
        echo '</span>';
    }
    if (isset($options['help'])) {
        echo '<span class="help-block">' . $options['help'] . '</span>';
    }
}

$alert = '';
$expirationDateAlert = '';

if (isset($_POST['set-new-password'])) {
    $password = filter_input(INPUT_POST, 'password', FILTER_SANITIZE_STRING);
    $retypedPassword = filter_input(INPUT_POST, 'password-retyped', FILTER_SANITIZE_STRING);
    if ($password === $retypedPassword) {
        $cred = fopen(PERSISTENT_DATA_DIR . DIRECTORY_SEPARATOR . 'credentials.txt', 'w');
        flock($cred, LOCK_EX) or die('Cannot read credentials');
        fwrite($cred, sha1($password));
        flock($cred, LOCK_UN);
        $alert = make_alert_success('Password modificata con successo.');
    } else {
        $alert = make_alert_error('Le password non corrispondono.');
    }
} else if (isset($_POST['set-expiry-date'])) {
    $options = ['options' => ['regexp' => '/\d\d?/', 'default' => '0']];
    $year  = filter_input(INPUT_POST, 'year',  FILTER_VALIDATE_INT, ['options' => ['min_range' => 2000, 'default' => 2016]]);
    $month = filter_input(INPUT_POST, 'month', FILTER_VALIDATE_REGEXP, $options);
    $day   = filter_input(INPUT_POST, 'day',   FILTER_VALIDATE_REGEXP, $options);
    $hour  = filter_input(INPUT_POST, 'hour',  FILTER_VALIDATE_REGEXP, $options);
    $min   = filter_input(INPUT_POST, 'min',   FILTER_VALIDATE_REGEXP, $options);
    $sec   = filter_input(INPUT_POST, 'sec',   FILTER_VALIDATE_REGEXP, $options);
    $dateString = "$year-$month-$day $hour:$min:$sec";
    
    if (date_create($dateString) !== false) {
        $activation = fopen(ACTIVATION_FILE, 'w+'); // apri in sola scrittura, tronca il file ed eventualmente crealo
        fwrite($activation, $dateString);
        $expirationDateAlert = make_alert_success('Scadenza modificata con successo.');
    } else {
        $expirationDateAlert = make_alert_error('Data non valida: ' . $dateString);
    }
}
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <link rel="stylesheet" href="/static/css/single-form-page.css"/>
        <title>Cambia password</title>
    </head>
    <body>
	<div class="container">
            <div class="panel panel-default">
                <div class="panel-heading"><h1 class="panel-title">Cambia password</h1></div>
                <div class="panel-body">
                    <?= $alert ?>
                    <form method="POST" class="form-horizontal">
                        <input type="hidden" name="redir" value="<?= $redirect ?>"/>
                        <fieldset>
                            <div class="form-group">
                                <label class="col-sm-2">Nuova password</label>
                                <div class="col-sm-10"><input class="form-control" name="password" type="password"/></div>
                            </div>
                            <div class="form-group">
                                <label class="col-sm-2">Ripeti password</label>
                                <div class="col-sm-10"><input class="form-control" name="password-retyped" type="password"/></div>
                            </div>
                        </fieldset>
                        <div class="form-group">
                            <div class="col-sm-offset-2 col-sm-10">
                                <a href="<?= $redirect ?>" class="btn btn-primary">
                                    <span class="glyphicon glyphicon-chevron-left"></span> Annulla
                                </a>
                                <button type="submit" name="set-new-password" class="btn btn-primary">
                                    <span class="glyphicon glyphicon-pencil"></span> Salva
                                </button>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
            <?php if ($access->isMaster) { ?>
                <div class="panel panel-default">
                    <div class="panel-heading"><h1 class="panel-title">Imposta data di scadenza</h1></div>
                    <div class="panel-body">
                        <?= $expirationDateAlert ?>
                        <form method="POST" class="form-horizontal">
                            <input type="hidden" name="redir" value="<?= $redirect ?>"/>
                            <fieldset>
                                <div class="form-group">
                                    <label class="col-sm-2 control-label">Scadenza corrente</label>
                                    <div class="col-sm-10">
                                        <p class="form-control-static"><?= date(DATE_FORMAT, AccessControl::readExpiration()) ?></p>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <label class="col-sm-2 control-label">Nuova scadenza</label>
                                    <div class="col-sm-10">
                                        <div class="input-group">
                                            <?php
                                            make_bootstrap_form_input(
                                                    ['name' => 'year', 'type' => 'number', 'min' => 0, 'title' => 'Anno', 'required' => 'true'],
                                                    ['addon' => 'AA']);
                                            make_bootstrap_form_input(
                                                    ['name' => 'month', 'type' => 'number', 'min' => 1, 'max' => 12, 'title' => 'Mese', 'required' => 'true'],
                                                    ['addon' => 'MM']);
                                            make_bootstrap_form_input(
                                                    ['name' => 'day', 'type' => 'number', 'min' => 1, 'max' => 31, 'title' => 'Giorno', 'required' => 'true'],
                                                    ['addon' => 'gg']);
                                            ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="form-group">
                                    <div class="col-sm-offset-2 col-sm-10">
                                        <div class="input-group">
                                            <?php
                                            make_bootstrap_form_input(
                                                    ['name' => 'hour', 'type' => 'number', 'min' => 0, 'max' => 23, 'title' => 'Ore'],
                                                    ['addon' => 'hh']);
                                            make_bootstrap_form_input(
                                                    ['name' => 'min', 'type' => 'number', 'min' => 0, 'max' => 59, 'title' => 'Minuti'],
                                                    ['addon' => 'mm']);
                                            make_bootstrap_form_input(
                                                    ['name' => 'sec', 'type' => 'number', 'min' => 0, 'max' => 59, 'title' => 'Secondi'],
                                                    ['addon' => 'ss'])
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            </fieldset>
                            <div class="form-group">
                                <div class="col-sm-offset-2 col-sm-10">
                                    <a href="<?= $redirect ?>" class="btn btn-primary">
                                        <span class="glyphicon glyphicon-chevron-left"></span> Annulla
                                    </a>
                                    <button type="submit" name="set-expiry-date" class="btn btn-primary">
                                        <span class="glyphicon glyphicon-pencil"></span> Salva
                                    </button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            <?php } ?>
	</div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>