<?php
require_once 'includes/access.php';

const ARCHIVE_DIR = '/root/dp18/archive';

const ACTION_REMOVE_ALL    = 'remove-all';
const ACTION_REMOVE_ALARMS = 'remove-alarms';
const ACTION_REMOVE_LOGS   = 'remove-logs';
const ACTION_REMOVE_DATA   = 'remove-data';
const ACTION_REMOVE_EMAILS = 'remove-emails';

function unlink_all_matching($dir, $predicate) {
    while (false !== ($entry = $dir->read())) {
        if ($entry !== '.' && $entry !== '..' && call_user_func($predicate, $entry)) {
            unlink($dir->path . DIRECTORY_SEPARATOR . $entry);
        }
    }
}

function count_dir($directory) {
    try {
        $iter = new FilesystemIterator($directory, FilesystemIterator::SKIP_DOTS);
        return iterator_count($iter);
    } catch (Exception $ex) {
        return -1;
    }
}

$archiveDir = dir(ARCHIVE_DIR);

if ($_POST) {
    $action = filter_input(INPUT_POST, 'action', FILTER_SANITIZE_STRING);
    switch ($action) {
        case ACTION_REMOVE_ALL:
            unlink_all_matching($archiveDir, function($entry) { return true; });
            break;
        case ACTION_REMOVE_ALARMS:
            unlink_all_matching($archiveDir, function($entry) { return strstr($entry, 'Alarm') !== false; });
            break;
        case ACTION_REMOVE_LOGS:
            unlink_all_matching($archiveDir, function($entry) { return strstr($entry, 'Log') !== false; });
            break;
        case ACTION_REMOVE_DATA:
            unlink_all_matching($archiveDir, function($entry) { return strstr($entry, 'Data') !== false; });
            break;
        case ACTION_REMOVE_EMAILS:
            unlink_all_matching($archiveDir, function($entry) { return pathinfo($entry, PATHINFO_EXTENSION) === 'mail'; });
            break;
        default: // non fare niente
    }
    $archiveDir->rewind();
}

$nFiles = 0;
$nAlarms = 0;
$nLogs = 0;
$nData = 0;
$nMails = 0;
while (false !== ($entry = $archiveDir->read())) {
    if ($entry === '.' || $entry === '..') {
        continue;
    }
    switch (pathinfo($entry, PATHINFO_EXTENSION)) {
        case 'xml': // data o log
            if (strstr($entry, 'Data') !== false) {
                ++$nData;
            } else if (strstr($entry, 'Log') !== false) {
                ++$nLogs;
            } else if (strstr($entry, 'Alarm') !== false) {
                ++$nAlarms;
            }
            break;
        case 'eml': ++$nMails; break;
    }
    ++$nFiles;
}
$archiveDir->close();
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <title>Archivio</title>
        <style>
            button, form a { min-width: 240px }
            @media (max-width: 768px) {
                button, form a { min-width: 0px }
            }
        </style>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div class="page-header"><h1>Archivio</h1></div>
            <div class="row">
                <div class="col-sm-9">
                    <form class="form-horizontal" method="POST">
                        <input type="hidden" name="action" value="<?= ACTION_REMOVE_ALL ?>"/>
                        <div class="form-group">
                            <label class="col-xs-3 col-sm-4 control-label">Archivio file inviati</label>
                            <div class="col-xs-9 col-sm-8">
                                <p class="form-control-static">Contiene <strong><?= $nFiles ?></strong> file.</p>
                                <span class="help-block">Numero di file totali archiviati tra allarmi, log eventi, riepiloghi e email.</span>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                                <button type="submit" class="btn btn-default">
                                    <span class="glyphicon glyphicon-trash"></span> Rimuovi tutti i file archiviati
                                </button>
                            </div>
                        </div>
                    </form>
                    <hr/>
                    <form class="form-horizontal" method="POST">
                        <input type="hidden" name="action" value="<?= ACTION_REMOVE_ALARMS ?>"/>
                        <div class="form-group">
                            <label class="col-xs-3 col-sm-4 control-label">Allarmi notificati</label>
                            <div class="col-xs-9 col-sm-8">
                                <p class="form-control-static">Contiene <strong><?= $nAlarms ?></strong> allarmi.</p>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                                <button type="submit" class="btn btn-default">
                                    <span class="glyphicon glyphicon-trash"></span> Rimuovi tutti gli allarmi
                                </button>
                            </div>
                        </div>
                    </form>
                    <hr/>
                    <form class="form-horizontal" method="POST">
                        <input type="hidden" name="action" value="<?= ACTION_REMOVE_LOGS ?>"/>
                        <div class="form-group">
                            <label class="col-xs-3 col-sm-4 control-label">File di log</label>
                            <div class="col-xs-9 col-sm-8">
                                <p class="form-control-static">Contiene <strong><?= $nLogs ?></strong> file.</p>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                                <button type="submit" class="btn btn-default">
                                    <span class="glyphicon glyphicon-trash"></span> Rimuovi tutti i log
                                </button>
                            </div>
                        </div>
                    </form>
                    <hr/>
                    <form class="form-horizontal" method="POST">
                        <input type="hidden" name="action" value="<?= ACTION_REMOVE_DATA ?>"/>
                        <div class="form-group">
                            <label class="col-xs-3 col-sm-4 control-label">Riepiloghi</label>
                            <div class="col-xs-9 col-sm-8">
                                <p class="form-control-static">Contiene <strong><?= $nData ?></strong> file.</p>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                                <a href="/data_file_viewer.php" class="btn btn-primary">
                                    <span class="glyphicon glyphicon-search"></span> Visualizza i riepiloghi archiviati
                                </a>
                                <button type="submit" class="btn btn-default">
                                    <span class="glyphicon glyphicon-trash"></span> Rimuovi tutti i riepiloghi
                                </button>
                            </div>
                        </div>
                    </form>
                    <hr/>
                    <form class="form-horizontal" method="POST">
                        <input type="hidden" name="action" value="<?= ACTION_REMOVE_EMAILS ?>"/>
                        <div class="form-group">
                            <label class="col-xs-3 col-sm-4 control-label">Email spedite</label>
                            <div class="col-xs-9 col-sm-8">
                                <p class="form-control-static">Contiene <strong><?= $nMails ?></strong> file.</p>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-xs-offset-3 col-xs-9 col-sm-offset-4 col-sm-8">
                                <a href="/sent_mail_viewer.php" class="btn btn-primary">
                                    <span class="glyphicon glyphicon-search"></span> Visualizza le mail archiviate
                                </a>
                                <button type="submit" class="btn btn-default">
                                    <span class="glyphicon glyphicon-trash"></span> Rimuovi tutte le email
                                </button>
                            </div>
                        </div>
                    </form>
                </div>
                <div class="col-sm-3">
                    <div class="panel panel-primary">
                        <div class="panel-heading"><h1 class="panel-title">File in uscita</h1></div>
                        <ul class="list-group">
                            <li class="list-group-item"><span class="badge"><?= count_dir('/root/dp18/outgoing') ?></span> Via (S)FTP</li>
                            <li class="list-group-item"><span class="badge"><?= count_dir('/root/dp18/mailbox') ?></span> Via email</li>
                            <li class="list-group-item"><span class="badge"><?= count_dir('/root/dp18/drafts') ?></span> Rimandati</li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>
