<?php
require_once 'includes/access.php';
require_once 'includes/bootstrap_forms.php';
require_once 'includes/workspace.php';

define('CONFIG_MOD_FILE', workspace_get('DP18.ini'));

function print_section($out, $dict, $section = NULL) {
    fputs($out, (isset($section) ? "[$section]" : '[General]') . "\n");
    foreach ($dict as $key => $value) {
        fputs($out, "$key=\"$value\"\n");
    }
}

function save_config_to($outfile, $dictionary) {
    foreach ($dictionary as $sectionName => $sectionDict) {
        print_section($outfile, $sectionDict, $sectionName);
        fputs($outfile, "\n");
    }
}

// creo il file di modifiche
if ($_POST) {
    $outfile = fopen(CONFIG_MOD_FILE, 'w');
    save_config_to($outfile, $_POST);
    fclose($outfile);
}

// fondo insieme i due file di impostazioni
$settings = parse_ini_file('/root/dp18/microhard/DP18.ini', true, INI_SCANNER_RAW);
if (is_readable(CONFIG_MOD_FILE)) {
    $modSettings = parse_ini_file(CONFIG_MOD_FILE, true, INI_SCANNER_RAW);
    $settings = array_replace_recursive($settings, $modSettings);
}

if (isset($_GET['export'])) {
    make_download_headers($selectedFile);
    exit;
} else if (isset($_GET['raw'])) {
    $tmp = tempnam('/tmp', 'delthis');
    $out = fopen($tmp, 'w');
    save_config_to($out, $settings);
    make_raw_headers($tmp);
    fclose($out);
    exit;
}

const LANGUAGES = ['it' => 'Italiano', 'en' => 'Inglese'];
const HOPPER_VALUES = [5 => '5 cent', 10 => '10 cent', 20 => '20 cent', 50 => '50 cent', 100 => '1 euro', 200 => '2 euro'];
const FILE_TRANSFER_PROTOCOL = ['ftp' => 'FTP', 'sftp' => 'SFTP'];
const IP_ADDRESS = ['dynamic' => 'Dinamico con DHCP', 'static' => 'Statico'];
const ALARMS = [
    'battery-power' => 'Funzionamento a batteria',
    'board-unresponsive' => 'Scheda di controllo in errore',
    'tamper' => 'Macchina manomessa',
    'products-not-available' => 'Prodotti non disponibili',
    'cannot-accept-money' => 'Impossibile immettere credito',
    'touchscreen-disconnected' => 'Touchscreen non collegato'
];
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <title>Impostazioni</title>
    </head>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div class="page-header">
                <h1>
                    <a title="Esporta" href="?export"><span class="glyphicon glyphicon-download"></span></a>
                    <a title="Visualizza testo" href="?raw"><span class="glyphicon glyphicon-file"></span></a>
                    Impostazioni di configurazione
                </h1>
            </div>
            <?php include 'includes/pending_changes_template.php' ?>
            <form class="form-horizontal" method="post">
                <div class="row">
                    <fieldset class="col-sm-6">
                        <legend>Generale</legend>
                        <?php make_bootstrap_combo('Lingua di default', $settings, 'General', 'default-language', LANGUAGES) ?>
                        <?php make_bootstrap_input('Ripristino lingua',
                                $settings,
                                'General',
                                'restore-default-language-timeout',
                                ['type' => 'number', 'min' => 0],
                                ['addon' => 'secondi']) ?>
                        <?php make_bootstrap_combo('Valore Hopper 1', $settings, 'General', 'hopper-value_1', HOPPER_VALUES) ?>
                        <?php make_bootstrap_combo('Valore Hopper 2', $settings, 'General', 'hopper-value_2', HOPPER_VALUES) ?>
                        <?php make_bootstrap_input('Attesa breve',
                                $settings,
                                'General',
                                'short-wait',
                                ['type' => 'number', 'min' => 0],
                                ['addon' => 'secondi']) ?>
                        <?php make_bootstrap_input('Attesa lunga',
                                $settings,
                                'General',
                                'long-wait',
                                ['type' => 'number', 'min' => 0],
                                ['addon' => 'secondi']) ?>
                        <?php make_bootstrap_input('Resto massimo',
                                $settings,
                                'General',
                                'max-change',
                                ['type' => 'number', 'min' => 0],
                                ['addon' => 'centesimi di <span class="glyphicon glyphicon-euro"></span>']) ?>
                        <?php make_bootstrap_input('Credito massimo',
                                $settings,
                                'General',
                                'max-credit',
                                ['type' => 'number', 'min' => 0],
                                ['addon' => 'centesimi di <span class="glyphicon glyphicon-euro"></span>']) ?>
                        <?php make_bootstrap_input('Messaggio della farmacia',
                                $settings,
                                'General',
                                'user-text',
                                ['type' => 'text'],
                                ['addon' => glyphicon('pencil')]) ?>
                        <div class="form-group">
                            <div class="checkbox col-xs-offset-4 col-sm-offset-4">
                                <?php make_bootstrap_checkbox('Usa barriera ottica', $settings, 'General', 'use-optical-barrier') ?>
                            </div>
                            
                        </div>
                        <legend>Scontrino</legend>
                        <?php
                        for ($i = 1; $i < 4; ++$i) {
                            make_bootstrap_input("Riga $i",
                                    $settings,
                                    'General',
                                    "receipt-row-$i",
                                    ['type' => 'text', 'maxlength' => 24],
                                    // testo di aiuto solo nell'ultimo campo
                                    ['addon' => glyphicon('header'), 'help' => ($i == 3 ? 'Lunghezza massima di 24 caratteri.' : null)]);
                        }
                        ?>
                        <legend>Impostazioni Avanzate</legend>
                        <div class="form-group">
                            <label class="col-sm-4 control-label">Numero di serie</label>
                            <div class="col-sm-8">
                                <input type="text" class="form-control" readonly value="<?= filter_var($settings['advanced']['serial'], FILTER_VALIDATE_INT) ?>"/>
                            </div>
                        </div>
                        <div class="form-group">
                            <label class="col-sm-4 control-label">Email assistenza</label>
                            <div class="col-sm-8">
                                <div class="input-group">
                                    <input type="text" class="form-control" readonly value="<?= filter_var($settings['advanced']['support-email'], FILTER_SANITIZE_STRING) ?>"/>
                                    <span class="input-group-addon">@</span>
                                </div>
                            </div>
                        </div>
                    </fieldset>
                    <fieldset class="col-sm-6">
                        <legend>Allarmi e Notifiche</legend>
                        <?php make_bootstrap_input(
                                        'Email per notifiche',
                                        $settings,
                                        'Alarms',
                                        'email',
                                        ['type' => 'email', 'multiple' => true],
                                        ['addon' => '@']) ?>
                        <div class="form-group">
                            <div class="checkbox col-xs-offset-4 col-sm-offset-4">
                                <?php make_bootstrap_checkbox('Abilita notifiche', $settings, 'General', 'enable-notifications') ?>
                            </div>
                        </div>
                        <div class="form-group">
                            <label class="col-xs-4 col-sm-4 control-label checkbox">Allarmi attivi</label>
                            <?php foreach (ALARMS as $key => $title) { ?>
                            <div class="checkbox col-xs-offset-4 col-sm-offset-4">
                                <?php make_bootstrap_checkbox($title, $settings, 'Alarms', $key, ['false' => 0, 'true' => 1]) ?>
                            </div>
                            <?php } ?>
                        </div>
                        <legend>Operazioni Pianificate</legend>
                        <?php make_bootstrap_input('Invio log e contabilità',
                                $settings,
                                'Schedule',
                                'ftp-transfer',
                                ['type' => 'time', 'pattern' => '[0-2]\d:[0-6]\d', 'title' => 'Inserisci un orario valido nel formato hh:mm'],
                                ['addon' => glyphicon('time')]) ?>
                        <?php make_bootstrap_input('Aggiornamento da remoto',
                                $settings,
                                'Schedule',
                                'remote-update',
                                ['type' => 'time', 'pattern' => '[0-2]\d:[0-6]\d', 'title' => 'Inserisci un orario valido nel formato hh:mm'],
                                ['addon' => glyphicon('time')]) ?>
                        <legend>Server FTP</legend>
                        <?php make_bootstrap_combo('Protocollo', $settings, 'FtpServer', 'protocol', FILE_TRANSFER_PROTOCOL) ?>
                        <?php make_bootstrap_input('Porta',
                                $settings,
                                'FtpServer',
                                'port',
                                ['type' => 'number', 'min' => 1, 'max' => 65535, 'autocomplete' => 'off']) ?>
                        <?php make_bootstrap_input('Indirizzo',
                                $settings, 
                                'FtpServer',
                                'address',
                                ['type' => 'text'],
                                ['addon' => glyphicon('globe')]) ?>
                        <?php make_bootstrap_input('Username',
                                $settings,
                                'FtpServer',
                                'username',
                                ['type' => 'text']) ?>
                        <?php make_bootstrap_input('Password',
                                $settings,
                                'FtpServer',
                                'password',
                                ['type' => 'text']) ?>
                        <legend>Server Aggiornamenti</legend>
                        <?php make_bootstrap_input('Indirizzo',
                                $settings, 
                                'UpdatesServer',
                                'address',
                                ['type' => 'text'],
                                ['addon' => glyphicon('globe')]) ?>
                        <legend>Configurazione di Rete</legend>
                        <?php make_bootstrap_combo('Metodo', $settings, 'Network', 'host-method', IP_ADDRESS) ?>
                        <?php make_bootstrap_input('Indirizzo IP',
                                $settings,
                                'NetworkConfig',
                                'ip',
                                ['type' => 'text', 'pattern' => IP_PATTERN]) ?>
                        <?php make_bootstrap_input('Netmask',
                                $settings,
                                'NetworkConfig',
                                'netmask',
                                ['type' => 'number', 'min' => 0, 'max' => 24, 'title' => 'Numero da 0 a 24']) ?>
                        <?php make_bootstrap_input('Gateway',
                                $settings,
                                'NetworkConfig',
                                'gateway',
                                ['type' => 'text', 'pattern' => IP_PATTERN]) ?>
                        <?php make_bootstrap_input('DNS',
                                $settings,
                                'NetworkConfig',
                                'dns',
                                ['type' => 'text', 'pattern' => IP_PATTERN]) ?>
                    </fieldset>
                </div>
                <div class="form-group">
                    <div class="col-sm-offset-3 col-sm-6">
                        <button type="submit" class="form-control btn btn-primary">
                            <span class="glyphicon glyphicon-pencil"></span> Applica
                        </button>
                    </div>
                </div>
            </form>
        </div>
    <?php include 'templates/footer.php' ?>
    </body>
</html>
