<?php

const LOCKFILE = '/run/dp18-web-frontend/login';
const ACTIVATION_FILE = '/var/lib/dp18-web-frontend/activation';
const DATE_FORMAT = 'Y-m-d H:i:s'; // anno-mese-giorno ore:minuti:secondi

class AccessControl {
    public $loggedIn;
    public $isMaster;
    public $isActive;
    public $expirationDate;
    public $loggedIp;
    private $loggedUserFile;
    
    public function __construct() {
        $this->loggedIn = false;
        $this->isMaster = false;
        $this->isActive = false;
        $this->expirationDate = null;
        $this->loggedIp = '';
        
        $this->loggedUserFile = fopen(LOCKFILE, 'c+');
        flock($this->loggedUserFile, LOCK_EX) or die('Cannot aquire lock');
        
        $loginData = file_get_contents(LOCKFILE);
        if ($loginData !== false) {
            $tokens = explode(' ', trim($loginData));
            $this->loggedIp = $tokens[0];
            $this->loggedIn = $_SERVER['REMOTE_ADDR'] === $this->loggedIp;
            $this->isMaster = filter_var($tokens[1], FILTER_VALIDATE_BOOLEAN, [ 'options' => [ 'default' => false ]]);
        }
        
        $contents = file_get_contents(ACTIVATION_FILE);
        if ($contents !== false) {
            $this->isActive = true;
            $this->expirationDate = strtotime(trim($contents));
        }
    }
    
    public function __destruct() {
        flock($this->loggedUserFile, LOCK_UN);
        fclose($this->loggedUserFile);
    }
    
    public function isUsable() {
        return $this->isActive && !$this->isExpired();
    }
    
    public function isExpired() {
        // anche se expirationDate non è inizializzato, il confronto con null restituisce false
        return time() > $this->expirationDate;
    }
    
    public function remainingTimeSec() {
        $now = time();
        if ($this->expirationDate >= $now) {
            return $this->expirationDate - $now;
        } else {
            return 0;
        }
    }
    
    public function checkAccess() {
        return $this->loggedIn && ($this->isMaster || $this->isUsable());
    }
    
    public function login($master) {
        $this->loggedIn = true;
        $this->isMaster = $master;
        
        ftruncate($this->loggedUserFile, 0); // l'apertura con modalità c+ non tronca il file
        // scrivo l'IP da cui si collega il client per determinare se è un nuovo client e annoto la tipologia di utente (utente normale o master)
        fwrite($this->loggedUserFile, $_SERVER['REMOTE_ADDR'] . ' ' . (int) $this->isMaster);
    }
    
    public function logout() {
        if ($this->loggedIn) {
            $this->loggedIn = false;
            $this->isMaster = false;
            
            ftruncate($this->loggedUserFile, 0);
        }
    }
    
    static public function readExpiration() {
        $contents = file_get_contents(ACTIVATION_FILE);
        if ($contents !== false) {
            return strtotime(trim($contents));
        } else {
            return false;
        }
    }
}
