<?php
require_once 'includes/access.php';
require_once 'includes/util.php';
require_once 'includes/products.php';
require_once 'includes/workspace.php';
require_once 'includes/product_images.php';

const MOD_FILE = 'mod.xml';

$manifests = get_catalogue_manifests(CATALOGUE_BASE);
$products = deserialize_catalogues(...$manifests);
apply_modifications($products, workspace_get(MOD_FILE));

// ignoro il file di modifiche alle impostazioni perché non permetto di cambiare le selezioni in remoto
$settings = parse_ini_file('/root/dp18/microhard/DP18.ini', true, INI_SCANNER_RAW);
$arrangement = $settings['Products'];

$remainingSec = $access->remainingTimeSec();

function make_product_cell($i) {
    global $arrangement;
    global $products;
    if (isset($products[$arrangement["selection_$i"]])) {
        $prod = $products[$arrangement["selection_$i"]];
?>
<td>
    <div data-cell-id="<?= $i ?>" class="product empty">
        <img src="<?= get_thumbnail_url($prod) ?>" data-toggle="tooltip" title="<?= $prod->name ?>"/>
        <a href="/product_list.php#<?= htmlspecialchars($prod->full_id) ?>">
            <span class="glyphicon glyphicon-euro"></span> <span><?= money_str($prod->prices[0]) ?></span>
        </a>
    </div>
</td>
<?php
    } else {
?>
<td>
    <div class="product error">
        <img src="/static/images/no-image.png"/>
        <span>NON ESISTE</span>
    </div>
</td>
<?php
    }
}
?>
<!DOCTYPE html>
<html>
    <head>
        <?php include 'templates/presentation_headers.php' ?>
        <link rel="stylesheet" href="/static/css/frontpage.css"/>
        <title>DP18 Web Frontend</title>
        <script type="text/javascript">
            function safeForEach(obj, callback) {
                if (obj !== undefined)
                    $.each(obj, callback)
            }
            
            $(function () {
                $('[data-toggle="tooltip"]').tooltip()
                
                var intervalId = setInterval(function() {
                    $.ajax({
                        method: 'GET',
                        url: '/includes/get_device_status.php',
                        data: { part: 'products' },
                        dataType: 'json',
                        timeout: 2500,
                        success: function (data) {
                            $('#timestamp').text(data.timestamp)
                            $.each(data.products || {}, function(offsetString, maskString) {
                                var offset = parseInt(offsetString, 10)
                                var mask = parseInt(maskString, 16)
                                for (var i = 0; i < 32; ++i) {
                                    var present = (mask >> i) & 0x1
                                    $('.product[data-cell-id=' + (offset + i) + ']').toggleClass('empty', !present)
                                }
                            })
                        },
                        error: function(xhr, status, errorStr) {
                            clearInterval(intervalId);
                            $('#status-error').show()
                        }
                    })
                }, 3000)
                
                <?php if ($remainingSec > 0 && !$access->isMaster) { ?>
                var remainingSec = <?= $remainingSec ?>;
                var SECONDS_IN_A_DAY = 24 * 3600
                setInterval(function() {
                    var days = Math.floor(remainingSec / SECONDS_IN_A_DAY)
                    var hours = Math.floor((remainingSec % SECONDS_IN_A_DAY) / 3600)
                    var minutes = Math.floor((remainingSec % 3600) / 60)
                    var seconds = remainingSec % 60
                    $('#remaining-time').html(days + ' giorni ' + hours + ' ore ' + minutes + ' minuti ' + seconds + ' secondi')
                    if (remainingSec > 0)
                        remainingSec -= 1
                }, 1000)
                <?php } ?>
            });
        </script>
    </head>
    <body>
        <?php include 'templates/navbar.php' ?>
        <div class="container">
            <div class="page-header"><h1>DP18 Touch <small><?= gethostname() ?></small></h1></div>
            <?php
            $remainingDays = $remainingSec / (3600 * 24);
            if ($remainingDays <= 10 && !$access->isMaster) { // l'utentee master non ha restrizioni di durata
            ?>
                <div class="alert alert-warning">
                    <p>
                        Rimangono <strong>meno di 10 giorni</strong> allo scadere del periodo di utilizzo.
                        Tempo rimasto <strong id="remaining-time"></strong>.
                    </p>
                    <p>
                        Scadenza il <strong><?= date(DATE_FORMAT, $access->expirationDate) ?></strong>.
                        <a href="renew.php" class="alert-link">
                            <span class="glyphicon glyphicon-envelope"></span> Richiedi il rinnovo ora.
                        </a>
                    </p>
                </div>
            <?php } ?>
            <div class="row">
                <section class="col-sm-6">
                    <h2>Selezioni <small>(al <span id="timestamp">???</span>)</small></h2>
                    <h2 id="status-error" class="text-danger" style="display: none">Attenzione: presenza prodotti non disponibile</h2>
                    <table>
                        <tr>
                            <?= make_product_cell(0) ?>
                            <td colspan="2"/>
                            <?= make_product_cell(1) ?>
                        </tr>
                        <?php
                        for ($row = 0; $row < 4; ++$row) {
                            echo '<tr>';
                            for ($col = 0; $col < 4; ++$col) {
                                $selection = $row * 4 + $col + 2;
                                make_product_cell($selection);
                            }
                            echo '</tr>';
                        }
                        ?>
                    </table>
                </section>
                <section class="col-sm-6">
                    <h2>Home Page</h2>
                    <?php
                    $mediaDir = dir('/root/dp18/data/media');
                    $slides = [];
                    while (false !== ($entry = $mediaDir->read())) {
                        if ($entry !== '.' && $entry !== '..') {
                            $slides[] = $entry;
                        }
                    }
                    ?>
                    <div id="carousel-outer">
                        <div id="home-page-slides" class="carousel slide" data-ride="carousel">
                            <!-- Indicators -->
                            <ol class="carousel-indicators">
                            <?php
                            foreach ($slides as $i => $slide) {
                                $activeClass = $i === 0 ? 'class="active"' : '';
                            ?>
                                <li data-target="#home-page-slides" data-slide-to="<?= $i ?>" <?= $activeClass ?>></li>
                            <?php } ?>
                            </ol>

                            <!-- Wrapper for slides -->
                            <div class="carousel-inner">
                                <?php
                                foreach ($slides as $i => $slide) {
                                    $activeClass = $i === 0 ? 'active' : '';
                                ?>
                                <div class="item <?= $activeClass ?>">
                                    <img src="/media/<?= $slide ?>">
                                </div>
                                <?php } ?>
                            </div>

                            <!-- Controls -->
                            <a class="left carousel-control" href="#home-page-slides" data-slide="prev">
                                <span class="glyphicon glyphicon-chevron-left"></span>
                            </a>
                            <a class="right carousel-control" href="#home-page-slides" data-slide="next">
                                <span class="glyphicon glyphicon-chevron-right"></span>
                            </a>
                        </div>
                    </div>
                </section>
            </div>
        </div>
        <?php include 'templates/footer.php' ?>
    </body>
</html>